# -*- coding:utf-8 -*-
# Copyright 2018 The TagWord Authors. All Rights Reserved.
# Name: TAGWORD点评采集器
# Contact: contact@tagword.cn
# Description: 点评采集器主程序
# ========================================================
from __future__ import absolute_import
from __future__ import division
from __future__ import print_function

__version__ = 1.0

