# -*- coding:utf-8 -*-
# Copyright 2017 The TAGWORD Authors. All Rights Reserved.
# Name: TAGWORD爬虫User-Agents列表
# Description: 数据通信交互部件，方便对User-Agent进行查询或替换
# Contact: contact@tagword.cn
# ==============================================================================
from __future__ import absolute_import
from __future__ import division
from __future__ import print_function

USER_AGENTS = [
    {'os': 'Safari for iOS',
     'ua': 'Mozilla/5.0 (iPhone; CPU iPhone OS 10_3_1 like Mac OS X) AppleWebKit/603.1.30 (KHTML, like Gecko) Version/10.0 Mobile/14E304 Safari/602.1',
     'type': 'mobile browsers'},
    {'os': 'Android Browser',
     'ua': 'Mozilla/5.0 (Linux; U; Android 4.4.2; en-us; SCH-I535 Build/KOT49H) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.0 Mobile Safari/534.30',
     'type': 'mobile browsers'},
    {'os': 'Chrome Mobile',
     'ua': 'Mozilla/5.0 (Linux; Android 7.0; SM-G930V Build/NRD90M) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/59.0.3071.125 Mobile Safari/537.36',
     'type': 'mobile browsers'},
    {'os': 'Opera Mini',
     'ua': 'Opera/9.80 (J2ME/MIDP; Opera Mini/5.1.21214/28.2725; U; ru) Presto/2.8.119 Version/11.10',
     'type': 'mobile browsers'},
    {'os': 'Opera Mini (iOS WebKit)',
     'ua': 'Mozilla/5.0 (iPhone; CPU iPhone OS 7_1_2 like Mac OS X) AppleWebKit/537.51.2 (KHTML, like Gecko) OPiOS/10.2.0.93022 Mobile/11D257 Safari/9537.53',
     'type': 'mobile browsers'},
    {'os': 'Firefox for Android',
     'ua': 'Mozilla/5.0 (Android 7.0; Mobile; rv:54.0) Gecko/54.0 Firefox/54.0',
     'type': 'mobile browsers'},
    {'os': 'Firefox for iOS',
     'ua': 'Mozilla/5.0 (iPhone; CPU iPhone OS 10_3_2 like Mac OS X) AppleWebKit/603.2.4 (KHTML, like Gecko) FxiOS/7.5b3349 Mobile/14F89 Safari/603.2.4',
     'type': 'mobile browsers'},
    {'os': 'UC Browser',
     'ua': 'Mozilla/5.0 (Linux; U; Android 7.0; en-US; SM-G935F Build/NRD90M) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.0 UCBrowser/11.3.8.976 U3/0.8.0 Mobile Safari/534.30"',
     'type': 'mobile browsers'},
    {'os': 'IE Mobile',
     'ua': 'Mozilla/5.0 (compatible; MSIE 10.0; Windows Phone 8.0; Trident/6.0; IEMobile/10.0; ARM; Touch; Microsoft; Lumia 950)',
     'type': 'mobile browsers'},
    {'os': 'Edge Mobile',
     'ua': 'Mozilla/5.0 (Windows Phone 10.0; Android 6.0.1; Microsoft; Lumia 950) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/52.0.2743.116 Mobile Safari/537.36 Edge/15.14977',
     'type': 'mobile browsers'},
    {'os': 'Apple iPhone XR (Safari)',
     'ua': 'Mozilla/5.0 (iPhone; CPU iPhone OS 12_0 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) CriOS/69.0.3497.105 Mobile/15E148 Safari/605.1',
     'type': 'iPhone'},
    {'os': 'Apple iPhone XS Max (Firefox)',
     'ua': 'Mozilla/5.0 (iPhone; CPU iPhone OS 12_0 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) FxiOS/13.2b11866 Mobile/16A366 Safari/605.1.15',
     'type': 'iPhone'},
    {'os': 'Apple iPhone X',
     'ua': 'Mozilla/5.0 (iPhone; CPU iPhone OS 11_0 like Mac OS X) AppleWebKit/604.1.38 (KHTML, like Gecko) Version/11.0 Mobile/15A372 Safari/604.1',
     'type': 'iPhone'},
    {'os': 'Apple iPhone 8',
     'ua': 'Mozilla/5.0 (iPhone; CPU iPhone OS 11_0 like Mac OS X) AppleWebKit/604.1.34 (KHTML, like Gecko) Version/11.0 Mobile/15A5341f Safari/604.1',
     'type': 'iPhone'},
    {'os': 'Apple iPhone 8 Plus',
     'ua': 'Mozilla/5.0 (iPhone; CPU iPhone OS 11_0 like Mac OS X) AppleWebKit/604.1.38 (KHTML, like Gecko) Version/11.0 Mobile/15A5370a Safari/604.1',
     'type': 'iPhone'},
    {'os': 'Apple iPhone 7',
     'ua': 'Mozilla/5.0 (iPhone9,3; U; CPU iPhone OS 10_0_1 like Mac OS X) AppleWebKit/602.1.50 (KHTML, like Gecko) Version/10.0 Mobile/14A403 Safari/602.1',
     'type': 'iPhone'},
    {'os': 'Apple iPhone 7 Plus',
     'ua': 'Mozilla/5.0 (iPhone9,4; U; CPU iPhone OS 10_0_1 like Mac OS X) AppleWebKit/602.1.50 (KHTML, like Gecko) Version/10.0 Mobile/14A403 Safari/602.1',
     'type': 'iPhone'},
    {'os': 'Apple iPhone 6',
     'ua': 'Mozilla/5.0 (Apple-iPhone7C2/1202.466; U; CPU like Mac OS X; en) AppleWebKit/420+ (KHTML, like Gecko) Version/3.0 Mobile/1A543 Safari/419.3',
     'type': 'iPhone'},
    {'os': 'Microsoft Lumia 650',
     'ua': 'Mozilla/5.0 (Windows Phone 10.0; Android 6.0.1; Microsoft; RM-1152) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/52.0.2743.116 Mobile Safari/537.36 Edge/15.15254',
     'type': 'MS Windows Phone'},
    {'os': 'Microsoft Lumia 550',
     'ua': 'Mozilla/5.0 (Windows Phone 10.0; Android 4.2.1; Microsoft; RM-1127_16056) AppleWebKit/537.36(KHTML, like Gecko) Chrome/42.0.2311.135 Mobile Safari/537.36 Edge/12.10536',
     'type': 'MS Windows Phone'},
    {'os': 'Microsoft Lumia 950',
     'ua': 'Mozilla/5.0 (Windows Phone 10.0; Android 4.2.1; Microsoft; Lumia 950) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/46.0.2486.0 Mobile Safari/537.36 Edge/13.1058',
     'type': 'MS Windows Phone'},
    {'os': 'Samsung Galaxy S9',
     'ua': 'Mozilla/5.0 (Linux; Android 8.0.0; SM-G960F Build/R16NW) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/62.0.3202.84 Mobile Safari/537.36',
     'type': 'Android Mobile'},
    {'os': 'Samsung Galaxy S8',
     'ua': 'Mozilla/5.0 (Linux; Android 7.0; SM-G892A Build/NRD90M; wv) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/60.0.3112.107 Mobile Safari/537.36',
     'type': 'Android Mobile'},
    {'os': 'Samsung Galaxy S7',
     'ua': 'Mozilla/5.0 (Linux; Android 7.0; SM-G930VC Build/NRD90M; wv) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/58.0.3029.83 Mobile Safari/537.36',
     'type': 'Android Mobile'},
    {'os': 'Samsung Galaxy S7 Edge',
     'ua': 'Mozilla/5.0 (Linux; Android 6.0.1; SM-G935S Build/MMB29K; wv) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/55.0.2883.91 Mobile Safari/537.36',
     'type': 'Android Mobile'},
    {'os': 'Samsung Galaxy S6',
     'ua': 'Mozilla/5.0 (Linux; Android 6.0.1; SM-G920V Build/MMB29K) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/52.0.2743.98 Mobile Safari/537.36',
     'type': 'Android Mobile'},
    {'os': 'Samsung Galaxy S6 Edge Plus',
     'ua': 'Mozilla/5.0 (Linux; Android 5.1.1; SM-G928X Build/LMY47X) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/47.0.2526.83 Mobile Safari/537.36',
     'type': 'Android Mobile'},
    {'os': 'Nexus 6P',
     'ua': 'Mozilla/5.0 (Linux; Android 6.0.1; Nexus 6P Build/MMB29P) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/47.0.2526.83 Mobile Safari/537.36',
     'type': 'Android Mobile'},
    {'os': 'Sony Xperia XZ',
     'ua': 'Mozilla/5.0 (Linux; Android 7.1.1; G8231 Build/41.2.A.0.219; wv) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/59.0.3071.125 Mobile Safari/537.36',
     'type': 'Android Mobile'},
    {'os': 'Sony Xperia Z5',
     'ua': 'Mozilla/5.0 (Linux; Android 6.0.1; E6653 Build/32.2.A.0.253) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/52.0.2743.98 Mobile Safari/537.36',
     'type': 'Android Mobile'},
    {'os': 'HTC One X10',
     'ua': 'Mozilla/5.0 (Linux; Android 6.0; HTC One X10 Build/MRA58K; wv) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/61.0.3163.98 Mobile Safari/537.36',
     'type': 'Android Mobile'},
    {'os': 'HTC One M9',
     'ua': 'Mozilla/5.0 (Linux; Android 6.0; HTC One M9 Build/MRA58K) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/52.0.2743.98 Mobile Safari/537.3',
     'type': 'Android Mobile'},
    {'os': 'Google Pixel C',
     'ua': 'Mozilla/5.0 (Linux; Android 7.0; Pixel C Build/NRD90M; wv) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/52.0.2743.98 Safari/537.36',
     'type': 'Tablet'},
    {'os': 'Sony Xperia Z4 Tablet',
     'ua': 'Mozilla/5.0 (Linux; Android 6.0.1; SGP771 Build/32.2.A.0.253; wv) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/52.0.2743.98 Safari/537.36',
     'type': 'Tablet'},
    {'os': 'Nvidia Shield Tablet K1',
     'ua': 'Mozilla/5.0 (Linux; Android 6.0.1; SHIELD Tablet K1 Build/MRA58K; wv) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/55.0.2883.91 Safari/537.36',
     'type': 'Tablet'},
    {'os': 'Samsung Galaxy Tab S3',
     'ua': 'Mozilla/5.0 (Linux; Android 7.0; SM-T827R4 Build/NRD90M) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/60.0.3112.116 Safari/537.36',
     'type': 'Tablet'},
    {'os': 'Samsung Galaxy Tab A',
     'ua': 'Mozilla/5.0 (Linux; Android 5.0.2; SAMSUNG SM-T550 Build/LRX22G) AppleWebKit/537.36 (KHTML, like Gecko) SamsungBrowser/3.3 Chrome/38.0.2125.102 Safari/537.36',
     'type': 'Tablet'},
    {'os': 'Amazon Kindle Fire HDX 7',
     'ua': 'Mozilla/5.0 (Linux; Android 4.4.3; KFTHWI Build/KTU84M) AppleWebKit/537.36 (KHTML, like Gecko) Silk/47.1.79 like Chrome/47.0.2526.80 Safari/537.36',
     'type': 'Tablet'},
    {'os': 'LG G Pad 7.0',
     'ua': 'Mozilla/5.0 (Linux; Android 5.0.2; LG-V410/V41020c Build/LRX22G) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/34.0.1847.118 Safari/537.36',
     'type': 'Tablet'},
    {'os': 'Windows 10-based PC using Edge browser',
     'ua': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/42.0.2311.135 Safari/537.36 Edge/12.246',
     'type': 'Desktop'},
    {'os': 'Chrome OS-based laptop using Chrome browser (Chromebook)',
     'ua': 'Mozilla/5.0 (X11; CrOS x86_64 8172.45.0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/51.0.2704.64 Safari/537.36',
     'type': 'Desktop'},
    {'os': 'Mac OS X-based computer using a Safari browser',
     'ua': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_11_2) AppleWebKit/601.3.9 (KHTML, like Gecko) Version/9.0.2 Safari/601.3.9',
     'type': 'Desktop'},
    {'os': 'Windows 7-based PC using a Chrome browser',
     'ua': 'Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/47.0.2526.111 Safari/537.36',
     'type': 'Desktop'},
    {'os': 'Linux-based PC using a Firefox browser',
     'ua': 'Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:15.0) Gecko/20100101 Firefox/15.0.1',
     'type': 'Desktop'},
    {'os': 'Chromecast',
     'ua': 'Mozilla/5.0 (CrKey armv7l 1.5.16041) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/31.0.1650.0 Safari/537.36',
     'type': 'Set Top Boxes'},
    {'os': 'Roku Ultra',
     'ua': 'Roku4640X/DVP-7.70 (297.70E04154A)',
     'type': 'Set Top Boxes'},
    {'os': 'Minix NEO X5',
     'ua': 'Mozilla/5.0 (Linux; U; Android 4.2.2; he-il; NEO-X5-116A Build/JDQ39) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.0 Safari/534.30',
     'type': 'Set Top Boxes'},
    {'os': 'Amazon 4K Fire TV',
     'ua': 'Mozilla/5.0 (Linux; Android 5.1; AFTS Build/LMY47O) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/41.99900.2250.0242 Safari/537.36',
     'type': 'Set Top Boxes'},
    {'os': 'Google Nexus Player',
     'ua': 'Dalvik/2.1.0 (Linux; U; Android 6.0.1; Nexus Player Build/MMB29T)',
     'type': 'Set Top Boxes'},
    {'os': 'Apple TV 5th Gen 4K',
     'ua': 'AppleTV6,2/11.1',
     'type': 'Set Top Boxes'},
    {'os': 'Apple TV 4th Gen',
     'ua': 'AppleTV5,3/9.1.1',
     'type': 'Set Top Boxes'},
    {'os': 'Nintendo Wii U',
     'ua': 'Mozilla/5.0 (Nintendo WiiU) AppleWebKit/536.30 (KHTML, like Gecko) NX/3.0.4.2.12 NintendoBrowser/4.3.1.11264.US',
     'type': 'Game Consoles'},
    {'os': 'Xbox One S',
     'ua': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64; XBOX_ONE_ED) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/51.0.2704.79 Safari/537.36 Edge/14.14393',
     'type': 'Game Consoles'},
    {'os': 'Xbox One',
     'ua': 'Mozilla/5.0 (Windows Phone 10.0; Android 4.2.1; Xbox; Xbox One) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/46.0.2486.0 Mobile Safari/537.36 Edge/13.10586',
     'type': 'Game Consoles'},
    {'os': 'Playstation 4',
     'ua': 'Mozilla/5.0 (PlayStation 4 3.11) AppleWebKit/537.73 (KHTML, like Gecko)',
     'type': 'Game Consoles'},
    {'os': 'Playstation Vita',
     'ua': 'Mozilla/5.0 (PlayStation Vita 3.61) AppleWebKit/537.73 (KHTML, like Gecko) Silk/3.2',
     'type': 'Game Consoles'},
    {'os': 'Nintendo 3DS',
     'ua': 'Mozilla/5.0 (Nintendo 3DS; U; ; en) Version/1.7412.EU',
     'type': 'Game Consoles'},
    {'os': 'Google bot',
     'ua': 'Mozilla/5.0 (compatible; Googlebot/2.1; +http://www.google.com/bot.html)',
     'type': 'Bots and Crawlers'},
    {'os': 'Bing bot',
     'ua': 'Mozilla/5.0 (compatible; bingbot/2.0; +http://www.bing.com/bingbot.htm)',
     'type': 'Bots and Crawlers'},
    {'os': 'Yahoo! bot',
     'ua': 'Mozilla/5.0 (compatible; Yahoo! Slurp; http://help.yahoo.com/help/us/ysearch/slurp)',
     'type': 'Bots and Crawlers'},
    {'os': 'Amazon Kindle 4',
     'ua': 'Mozilla/5.0 (X11; U; Linux armv7l like Android; en-us) AppleWebKit/531.2+ (KHTML, like Gecko) Version/5.0 Safari/533.2+ Kindle/3.0+',
     'type': 'E Readers'},
    {'os': 'Amazon Kindle 3',
     'ua': 'Mozilla/5.0 (Linux; U; en-US) AppleWebKit/528.5+ (KHTML, like Gecko, Safari/528.5+) Version/4.0 Kindle/3.0 (screen 600x800; rotate)',
     'type': 'E Readers'},
]
